@@ -16,9 +16,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __COMICS_DOCUMENT_H__
-#define __COMICS_DOCUMENT_H__
+#pragma once
 
+#include "ev-macros.h"
 #include "ev-document.h"
 
 G_BEGIN_DECLS
@@ -30,9 +30,8 @@ G_BEGIN_DECLS
 typedef struct _ComicsDocument ComicsDocument;
 
 GType                 comics_document_get_type (void) G_GNUC_CONST;
+GType                 register_atril_backend  (GTypeModule *module);
 
-G_MODULE_EXPORT GType register_atril_backend  (GTypeModule *module);
 
 G_END_DECLS
 
-#endif /* __COMICS_DOCUMENT_H__ */
