@@ -20,7 +20,7 @@
 #include <config.h>
 #include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
-#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #include "ev-file-helpers.h"
 #include "ev-attachment.h"
 
@@ -38,8 +38,8 @@ enum
 struct _EvAttachmentPrivate {
 	gchar                   *name;
 	gchar                   *description;
-	GTime                    mtime;
-	GTime                    ctime;
+	gint64                   mtime;
+	gint64                   ctime;
 	gsize                    size;
 	gchar                   *data;
 	gchar                   *mime_type;
@@ -48,20 +48,17 @@ struct _EvAttachmentPrivate {
 	GFile                   *tmp_file;
 };
 
-#define EV_ATTACHMENT_GET_PRIVATE(object) \
-                (G_TYPE_INSTANCE_GET_PRIVATE ((object), EV_TYPE_ATTACHMENT, EvAttachmentPrivate))
-
-G_DEFINE_TYPE (EvAttachment, ev_attachment, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (EvAttachment, ev_attachment, G_TYPE_OBJECT)
 
 GQuark
 ev_attachment_error_quark (void)
 {
 	static GQuark error_quark = 0;
-	
+
 	if (error_quark == 0)
 		error_quark =
 			g_quark_from_static_string ("ev-attachment-error-quark");
-	
+
 	return error_quark;
 }
 
@@ -152,8 +149,6 @@ ev_attachment_class_init (EvAttachmentClass *klass)
 
 	g_object_class->set_property = ev_attachment_set_property;
 
-	g_type_class_add_private (g_object_class, sizeof (EvAttachmentPrivate));
-
 	/* Properties */
 	g_object_class_install_property (g_object_class,
 					 PROP_NAME,
@@ -174,7 +169,7 @@ ev_attachment_class_init (EvAttachmentClass *klass)
 	g_object_class_install_property (g_object_class,
 					 PROP_MTIME,
 					 g_param_spec_ulong ("mtime",
-							     "ModifiedTime", 
+							     "ModifiedTime",
 							     "The attachment modification date",
 							     0, G_MAXULONG, 0,
 							     G_PARAM_WRITABLE |
@@ -202,14 +197,14 @@ ev_attachment_class_init (EvAttachmentClass *klass)
 							       "The attachment data",
 							       G_PARAM_WRITABLE |
 							       G_PARAM_CONSTRUCT_ONLY));
-	
+
 	g_object_class->finalize = ev_attachment_finalize;
 }
 
 static void
 ev_attachment_init (EvAttachment *attachment)
 {
-	attachment->priv = EV_ATTACHMENT_GET_PRIVATE (attachment);
+	attachment->priv = ev_attachment_get_instance_private (attachment);
 
 	attachment->priv->name = NULL;
 	attachment->priv->description = NULL;
@@ -222,8 +217,8 @@ ev_attachment_init (EvAttachment *attachment)
 EvAttachment *
 ev_attachment_new (const gchar *name,
 		   const gchar *description,
-		   GTime        mtime,
-		   GTime        ctime,
+		   gint64       mtime,
+		   gint64       ctime,
 		   gsize        size,
 		   gpointer     data)
 {
@@ -257,7 +252,7 @@ ev_attachment_get_description (EvAttachment *attachment)
 	return attachment->priv->description;
 }
 
-GTime
+gint64
 ev_attachment_get_modification_date (EvAttachment *attachment)
 {
 	g_return_val_if_fail (EV_IS_ATTACHMENT (attachment), 0);
@@ -265,7 +260,7 @@ ev_attachment_get_modification_date (EvAttachment *attachment)
 	return attachment->priv->mtime;
 }
 
-GTime
+gint64
 ev_attachment_get_creation_date (EvAttachment *attachment)
 {
 	g_return_val_if_fail (EV_IS_ATTACHMENT (attachment), 0);
@@ -296,28 +291,7 @@ ev_attachment_save (EvAttachment *attachment,
 	output_stream = g_file_replace (file, NULL, FALSE, 0, NULL, &ioerror);
 	if (output_stream == NULL) {
 		char *uri;
-		
-		uri = g_file_get_uri (file);
-		g_set_error (error,
-			     EV_ATTACHMENT_ERROR, 
-			     ioerror->code,
-			     _("Couldn't save attachment “%s”: %s"),
-			     uri, 
-			     ioerror->message);
 
-		g_error_free (ioerror);
-		g_free (uri);
-		
-		return FALSE;
-	}
-	
-	written_bytes = g_output_stream_write (G_OUTPUT_STREAM (output_stream),
-					       attachment->priv->data,
-					       attachment->priv->size,
-					       NULL, &ioerror);
-	if (written_bytes == -1) {
-		char *uri;
-		
 		uri = g_file_get_uri (file);
 		g_set_error (error,
 			     EV_ATTACHMENT_ERROR,
@@ -325,7 +299,28 @@ ev_attachment_save (EvAttachment *attachment,
 			     _("Couldn't save attachment “%s”: %s"),
 			     uri,
 			     ioerror->message);
-		
+
+		g_error_free (ioerror);
+		g_free (uri);
+
+		return FALSE;
+	}
+
+	written_bytes = g_output_stream_write (G_OUTPUT_STREAM (output_stream),
+					       attachment->priv->data,
+					       attachment->priv->size,
+					       NULL, &ioerror);
+	if (written_bytes == -1) {
+		char *uri;
+
+		uri = g_file_get_uri (file);
+		g_set_error (error,
+			     EV_ATTACHMENT_ERROR,
+			     ioerror->code,
+			     _("Couldn't save attachment “%s”: %s"),
+			     uri,
+			     ioerror->message);
+
 		g_output_stream_close (G_OUTPUT_STREAM (output_stream), NULL, NULL);
 		g_error_free (ioerror);
 		g_free (uri);
@@ -336,7 +331,7 @@ ev_attachment_save (EvAttachment *attachment,
 	g_output_stream_close (G_OUTPUT_STREAM (output_stream), NULL, NULL);
 
 	return TRUE;
-	
+
 }
 
 static gboolean
@@ -347,12 +342,8 @@ ev_attachment_launch_app (EvAttachment *attachment,
 {
 	gboolean           result;
 	GList             *files = NULL;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkAppLaunchContext *context;
 	GdkDisplay          *display;
-#else
-	GAppLaunchContext *context = NULL;
-#endif
 	GError            *ioerror = NULL;
 
 	g_assert (G_IS_FILE (attachment->priv->tmp_file));
@@ -360,7 +351,6 @@ ev_attachment_launch_app (EvAttachment *attachment,
 
 	files = g_list_prepend (files, attachment->priv->tmp_file);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	display = screen ? gdk_screen_get_display (screen) : gdk_display_get_default ();
 	context = gdk_display_get_app_launch_context (display);
 	gdk_app_launch_context_set_screen (context, screen);
@@ -370,17 +360,6 @@ ev_attachment_launch_app (EvAttachment *attachment,
 							    G_APP_LAUNCH_CONTEXT (context),
 							    &ioerror);
 	g_object_unref (context);
-#else
-	context = G_APP_LAUNCH_CONTEXT (gdk_app_launch_context_new ());
-	gdk_app_launch_context_set_screen (GDK_APP_LAUNCH_CONTEXT (context), screen);
-	gdk_app_launch_context_set_timestamp (GDK_APP_LAUNCH_CONTEXT (context), timestamp);
-
-	result = g_app_info_launch (attachment->priv->app, files,
-				    context, &ioerror);
-	
-	if (context)
-		g_object_unref (context);
-#endif
 
 	if (!result) {
 		g_set_error (error,
@@ -392,12 +371,12 @@ ev_attachment_launch_app (EvAttachment *attachment,
 
 		g_list_free (files);
 		g_error_free (ioerror);
-		
+
 		return FALSE;
 	}
 
 	g_list_free (files);
-	
+
 	return TRUE;
 }
 
@@ -411,7 +390,7 @@ ev_attachment_open (EvAttachment *attachment,
 	gboolean  retval = FALSE;
 
 	g_return_val_if_fail (EV_IS_ATTACHMENT (attachment), FALSE);
-	
+
 	if (!attachment->priv->app) {
 		app_info = g_app_info_get_default_for_type (attachment->priv->mime_type, FALSE);
 		attachment->priv->app = app_info;
@@ -423,7 +402,7 @@ ev_attachment_open (EvAttachment *attachment,
 			     0,
 			     _("Couldn't open attachment “%s”"),
 			     attachment->priv->name);
-		
+
 		return FALSE;
 	}
 
