@@ -31,6 +31,9 @@ G_BEGIN_DECLS
 
 typedef struct _EvMappingList EvMappingList;
 
+#define        EV_TYPE_MAPPING_LIST        (ev_mapping_list_get_type())
+GType          ev_mapping_list_get_type    (void) G_GNUC_CONST;
+
 EvMappingList *ev_mapping_list_new         (guint          page,
 					    GList         *list,
 					    GDestroyNotify data_destroy_func);
@@ -39,14 +42,19 @@ void           ev_mapping_list_unref       (EvMappingList *mapping_list);
 
 guint          ev_mapping_list_get_page    (EvMappingList *mapping_list);
 GList         *ev_mapping_list_get_list    (EvMappingList *mapping_list);
+void           ev_mapping_list_remove      (EvMappingList *mapping_list,
+					    EvMapping     *mapping);
 EvMapping     *ev_mapping_list_find        (EvMappingList *mapping_list,
 					    gconstpointer  data);
 EvMapping     *ev_mapping_list_find_custom (EvMappingList *mapping_list,
 					    gconstpointer  data,
 					    GCompareFunc   func);
-gpointer       ev_mapping_list_get_data    (EvMappingList *mapping_list,
+EvMapping     *ev_mapping_list_get         (EvMappingList *mapping_list,
 					    gdouble        x,
 					    gdouble        y);
+gpointer       ev_mapping_list_get_data    (EvMappingList *mapping_list,
+                                            gdouble        x,
+                                            gdouble        y);
 EvMapping     *ev_mapping_list_nth         (EvMappingList *mapping_list,
                                             guint          n);
 guint          ev_mapping_list_length      (EvMappingList *mapping_list);
