@@ -24,9 +24,6 @@
 
 #include "ev-progress-message-area.h"
 
-#define EV_PROGRESS_MESSAGE_AREA_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((obj), EV_TYPE_PROGRESS_MESSAGE_AREA, EvProgressMessageAreaPrivate))
-
 struct _EvProgressMessageAreaPrivate {
 	GtkWidget *label;
 	GtkWidget *progress_bar;
@@ -47,7 +44,7 @@ static void ev_progress_message_area_get_property (GObject      *object,
 						   GValue       *value,
 						   GParamSpec   *pspec);
 
-G_DEFINE_TYPE (EvProgressMessageArea, ev_progress_message_area, EV_TYPE_MESSAGE_AREA)
+G_DEFINE_TYPE_WITH_PRIVATE (EvProgressMessageArea, ev_progress_message_area, EV_TYPE_MESSAGE_AREA)
 
 static void
 ev_progress_message_area_class_init (EvProgressMessageAreaClass *class)
@@ -71,8 +68,6 @@ ev_progress_message_area_class_init (EvProgressMessageAreaClass *class)
 							      "The fraction of total work that has been completed",
 							      0.0, 1.0, 0.0,
 							      G_PARAM_READWRITE));
-
-	g_type_class_add_private (gobject_class, sizeof (EvProgressMessageAreaPrivate));
 }
 
 static void
@@ -80,13 +75,13 @@ ev_progress_message_area_init (EvProgressMessageArea *area)
 {
 	GtkWidget *contents;
 	GtkWidget *vbox;
-	
-	area->priv = EV_PROGRESS_MESSAGE_AREA_GET_PRIVATE (area);
+
+	area->priv = ev_progress_message_area_get_instance_private (area);
 
 	contents = _ev_message_area_get_main_box (EV_MESSAGE_AREA (area));
-	
+
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-	
+
 	area->priv->label = gtk_label_new (NULL);
 	gtk_label_set_use_markup (GTK_LABEL (area->priv->label), TRUE);
 	gtk_label_set_ellipsize (GTK_LABEL (area->priv->label),
@@ -191,7 +186,7 @@ ev_progress_message_area_set_fraction (EvProgressMessageArea *area,
 				       gdouble                fraction)
 {
 	g_return_if_fail (EV_IS_PROGRESS_MESSAGE_AREA (area));
-	
+
 	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (area->priv->progress_bar),
 				       fraction);
 	g_object_notify (G_OBJECT (area), "fraction");
